@@ -6,7 +6,7 @@ function(id, xy, date, burst=id, ...)
     if (ncol(xy)!=2)
       stop("xy should have two columns")
     if (!inherits(date, "POSIXct"))
-      stop("date should be of class \POSIXct\"")
+      stop("date should be of class \"POSIXct\"")
     id <- factor(id)
     burst <- factor(burst)
     if (!all(apply(table(id,burst)>0,2,sum)==1))
